@@ -29,8 +29,6 @@ from smartcard.Observer import Observable
 
 class CardConnection(Observable):
     """Card connection abstract class.
-
-    Known subclasses: smartcard.pcsc.PCSCCardConnection
     """
     T0_protocol = 0x00000001
     T1_protocol = 0x00000002
@@ -40,14 +38,14 @@ class CardConnection(Observable):
     def __init__(self, reader):
         """Construct a new card connection.
 
-        readerName: name of the reader in which the smartcard to connect
+        @param reader: name of the reader in which the smartcard to connect
         to is located.
         """
         Observable.__init__(self)
         self.reader = reader
         self.errorcheckingchain = None
         self.defaultprotocol = CardConnection.T0_protocol |\
-                                CardConnection.T1_protocol
+            CardConnection.T1_protocol
 
     def __del__(self):
         """Connect to card."""
@@ -56,37 +54,52 @@ class CardConnection(Observable):
     def addSWExceptionToFilter(self, exClass):
         """Add a status word exception class to be filtered.
 
-        exClass: the class to filter, e.g.
-        smartcard.sw.SWException.WarningProcessingException
+        @param exClass: the class to filter, e.g.
+        L{smartcard.sw.SWExceptions.WarningProcessingException}
 
         Filtered exceptions will not be raised when encountered in the
         error checking chain."""
-        if None != self.errorcheckingchain:
+        if self.errorcheckingchain is not None:
             self.errorcheckingchain[0].addFilterException(exClass)
 
     def addObserver(self, observer):
-        """Add a CardConnection observer."""
+        """Add a L{CardConnection} observer."""
         Observable.addObserver(self, observer)
 
     def deleteObserver(self, observer):
-        """Remove a CardConnection observer."""
+        """Remove a L{CardConnection} observer."""
         Observable.deleteObserver(self, observer)
 
     def connect(self, protocol=None, mode=None, disposition=None):
         """Connect to card.
-        protocol: a bit mask of the protocols to use, from
-        CardConnection.T0_protocol, CardConnection.T1_protocol,
-        CardConnection.RAW_protocol, CardConnection.T15_protocol
+        @param protocol: a bit mask of the protocols to use, from
+        L{CardConnection.T0_protocol}, L{CardConnection.T1_protocol},
+        L{CardConnection.RAW_protocol}, L{CardConnection.T15_protocol}
 
-        mode: SCARD_SHARE_SHARED (default), SCARD_SHARE_EXCLUSIVE or
+        @param mode: SCARD_SHARE_SHARED (default), SCARD_SHARE_EXCLUSIVE or
         SCARD_SHARE_DIRECT
 
-        disposition: SCARD_LEAVE_CARD (default), SCARD_RESET_CARD,
+        @param disposition: SCARD_LEAVE_CARD (default), SCARD_RESET_CARD,
         SCARD_UNPOWER_CARD or SCARD_EJECT_CARD
         """
         Observable.setChanged(self)
         Observable.notifyObservers(self, CardConnectionEvent('connect'))
 
+    def reconnect(self, protocol=None, mode=None, disposition=None):
+        """Reconnect to card.
+        @param protocol: a bit mask of the protocols to use, from
+        L{CardConnection.T0_protocol}, L{CardConnection.T1_protocol},
+        L{CardConnection.RAW_protocol}, L{CardConnection.T15_protocol}
+
+        @param mode: SCARD_SHARE_SHARED (default), SCARD_SHARE_EXCLUSIVE or
+        SCARD_SHARE_DIRECT
+
+        @param disposition: SCARD_LEAVE_CARD, SCARD_RESET_CARD (default),
+        SCARD_UNPOWER_CARD or SCARD_EJECT_CARD
+        """
+        Observable.setChanged(self)
+        Observable.notifyObservers(self, CardConnectionEvent('reconnect'))
+
     def disconnect(self):
         """Disconnect from card."""
         Observable.setChanged(self)
@@ -110,7 +123,7 @@ class CardConnection(Observable):
 
     def setErrorCheckingChain(self, errorcheckingchain):
         """Add an error checking chain.
-        errorcheckingchain: a smartcard.sw.ErrorCheckingChain object The
+        @param errorcheckingchain: a smartcard.sw.ErrorCheckingChain object The
         error checking strategies in errorchecking chain will be tested
         with each received response APDU, and a
         smartcard.sw.SWException.SWException will be raised upon
@@ -119,7 +132,7 @@ class CardConnection(Observable):
 
     def setProtocol(self, protocol):
         """Set protocol for card connection.
-        protocol: a bit mask of CardConnection.T0_protocol,
+        @param protocol: a bit mask of CardConnection.T0_protocol,
         CardConnection.T1_protocol, CardConnection.RAW_protocol,
         CardConnection.T15_protocol e.g.
         setProtocol(CardConnection.T1_protocol |
@@ -131,9 +144,9 @@ class CardConnection(Observable):
         and notify observers upon command/response APDU events.
         Subclasses must override the doTransmit() class method.
 
-        bytes:      list of bytes to transmit
+        @param bytes:      list of bytes to transmit
 
-        protocol:   the transmission protocol, from
+        @param protocol:   the transmission protocol, from
                     CardConnection.T0_protocol,
                     CardConnection.T1_protocol, or
                     CardConnection.RAW_protocol
@@ -149,7 +162,7 @@ class CardConnection(Observable):
                                    CardConnectionEvent(
                                        'response',
                                        [data, sw1, sw2]))
-        if None != self.errorcheckingchain:
+        if self.errorcheckingchain is not None:
             self.errorcheckingchain[0](data, sw1, sw2)
         return data, sw1, sw2
 
@@ -161,13 +174,14 @@ class CardConnection(Observable):
         pass
 
     def control(self, controlCode, bytes=[]):
-        """Send a control command and buffer.  Internally calls doControl()
-        class method and notify observers upon command/response events.
-        Subclasses must override the doControl() class method.
+        """Send a control command and buffer.  Internally calls
+        L{doControl()} class method and notify observers upon
+        command/response events.  Subclasses must override the
+        L{doControl()} class method.
 
-        controlCode: command code
+        @param controlCode: command code
 
-        bytes:       list of bytes to transmit
+        @param bytes:       list of bytes to transmit
         """
         Observable.setChanged(self)
         Observable.notifyObservers(self,
@@ -180,7 +194,7 @@ class CardConnection(Observable):
                                    CardConnectionEvent(
                                        'response',
                                        data))
-        if None != self.errorcheckingchain:
+        if self.errorcheckingchain is not None:
             self.errorcheckingchain[0](data)
         return data
 
@@ -193,7 +207,7 @@ class CardConnection(Observable):
     def getAttrib(self, attribId):
         """return the requested attribute
 
-        attribId: attribute id like SCARD_ATTR_VENDOR_NAME
+        @param attribId: attribute id like SCARD_ATTR_VENDOR_NAME
         """
         Observable.setChanged(self)
         Observable.notifyObservers(self,
@@ -201,7 +215,7 @@ class CardConnection(Observable):
                                        'attrib',
                                        [attribId]))
         data = self.doGetAttrib(attribId)
-        if None != self.errorcheckingchain:
+        if self.errorcheckingchain is not None:
             self.errorcheckingchain[0](data)
         return data
 
