@@ -3,7 +3,7 @@ when a CardConnection event occurs.
 
 __author__ = "http://www.gemalto.com"
 
-Copyright 2001-2010 gemalto
+Copyright 2001-2012 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
 
 This file is part of pyscard.
@@ -24,17 +24,17 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 """
 
 
-class CardConnectionEvent:
+class CardConnectionEvent(object):
     """Base class for card connection events.
 
-    This event is notified by CardConnection objects.
-
-    type:   'connect', 'disconnect', 'command', 'response'
-    args:   None for 'connect' or 'disconnect'
-            command APDU byte list for 'command'
-            [response data, sw1, sw2] for 'response'
-    type:   'connect'   args:"""
+    This event is notified by CardConnection objects."""
 
     def __init__(self, type, args=None):
+        """
+        @param type:   'connect', 'reconnect', 'disconnect', 'command', 'response'
+        @param args:   None for 'connect', 'reconnect' or 'disconnect'
+                command APDU byte list for 'command'
+                [response data, sw1, sw2] for 'response'
+        """
         self.type = type
         self.args = args
