@@ -53,7 +53,7 @@ class PCSCCardRequest(AbstractCardRequest):
         @param readers: the list of readers to consider for requesting a
         card default is to consider all readers
 
-        @param cardTypeClass: the CardType class to wait for; default is
+        @param cardType: the CardType class to wait for; default is
         AnyCardType, i.e.  the request will returns with new or already
         inserted cards
 
@@ -81,11 +81,20 @@ class PCSCCardRequest(AbstractCardRequest):
         self.hcontext = PCSCContext().getContext()
 
     def getReaderNames(self):
-        """Returns the list or PCSC readers on which to wait for cards."""
+        """Returns the list of PCSC readers on which to wait for cards."""
+
+        # renew the context in case PC/SC was stopped
+        # this happens on Windows when the last reader is disconnected
+        self.hcontext = PCSCContext().getContext()
 
         # get inserted readers
         hresult, pcscreaders = SCardListReaders(self.hcontext, [])
-        if 0 != hresult and SCARD_E_NO_READERS_AVAILABLE != hresult:
+        if hresult in (SCARD_E_SERVICE_STOPPED, SCARD_E_NO_SERVICE):
+            self.hcontext = PCSCContext().renewContext()
+            hresult, pcscreaders = SCardListReaders(self.hcontext, [])
+        if SCARD_E_NO_READERS_AVAILABLE == hresult:
+            return []
+        if SCARD_S_SUCCESS != hresult:
             raise ListReadersException(hresult)
 
         readers = []
@@ -127,14 +136,14 @@ class PCSCCardRequest(AbstractCardRequest):
                 readerstates[reader] = (reader, SCARD_STATE_UNAWARE)
 
         # remove dictionary entry for readers that disappeared
-        for oldreader in readerstates.keys():
+        for oldreader in list(readerstates.keys()):
             if oldreader not in readernames:
                 del readerstates[oldreader]
 
         # call SCardGetStatusChange only if we have some readers
         if {} != readerstates:
             hresult, newstates = SCardGetStatusChange(
-                self.hcontext, 0, readerstates.values())
+                self.hcontext, 0, list(readerstates.values()))
         else:
             hresult = 0
             newstates = []
@@ -189,14 +198,14 @@ class PCSCCardRequest(AbstractCardRequest):
                     readerstates[reader] = (reader, SCARD_STATE_UNAWARE)
 
             # remove dictionary entry for readers that disappeared
-            for oldreader in readerstates.keys():
+            for oldreader in list(readerstates.keys()):
                 if oldreader not in readernames:
                     del readerstates[oldreader]
 
             # wait for card insertion
             if {} != readerstates:
                 hresult, newstates = SCardGetStatusChange(
-                    self.hcontext, 0, readerstates.values())
+                    self.hcontext, 0, list(readerstates.values()))
             else:
                 hresult = SCARD_E_TIMEOUT
                 newstates = []
@@ -290,14 +299,14 @@ class PCSCCardRequest(AbstractCardRequest):
                 if not reader in readerstates:
                     readerstates[reader] = (reader, SCARD_STATE_UNAWARE)
             # remove dictionary entry for readers that disappeared
-            for oldreader in readerstates.keys():
+            for oldreader in list(readerstates.keys()):
                 if oldreader not in readernames:
                     del readerstates[oldreader]
 
             # get status change
             if {} != readerstates:
                 hresult, newstates = SCardGetStatusChange(
-                    self.hcontext, 0, readerstates.values())
+                    self.hcontext, 0, list(readerstates.values()))
             else:
                 hresult = 0
                 newstates = []
@@ -346,9 +355,9 @@ if __name__ == '__main__':
     """Small sample illustrating the use of PCSCCardRequest.py."""
 
     from smartcard.util import toHexString
-    print 'Insert a new card within 10 seconds'
+    print('Insert a new card within 10 seconds')
     cr = PCSCCardRequest(timeout=10, newcardonly=True)
     cs = cr.waitforcard()
     cs.connection.connect()
-    print cs.connection.getReader(), toHexString(cs.connection.getATR())
+    print(cs.connection.getReader() + ' ' + toHexString(cs.connection.getATR()))
     cs.connection.disconnect()
