@@ -2,7 +2,7 @@
 
 __author__ = "http://www.gemalto.com"
 
-Copyright 2001-2010 gemalto
+Copyright 2001-2012 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
 
 This file is part of pyscard.
@@ -28,7 +28,7 @@ from smartcard.scard import *
 from smartcard.pcsc.PCSCExceptions import EstablishContextException
 
 
-class PCSCContext:
+class PCSCContext(object):
     """Manage a singleton pcsc context handle."""
 
     class __PCSCContextSingleton:
@@ -42,6 +42,9 @@ class PCSCContext:
         def getContext(self):
             return self.hcontext
 
+        def releaseContext(self):
+            return SCardReleaseContext(self.hcontext)
+
     # the singleton
     mutex = RLock()
     instance = None
@@ -50,10 +53,23 @@ class PCSCContext:
         PCSCContext.mutex.acquire()
         try:
             if not PCSCContext.instance:
-                PCSCContext.instance = PCSCContext.__PCSCContextSingleton()
+                self.renewContext()
         finally:
             PCSCContext.mutex.release()
 
     def __getattr__(self, name):
         if self.instance:
             return getattr(self.instance, name)
+
+    def renewContext():
+        PCSCContext.mutex.acquire()
+        try:
+            if PCSCContext.instance is not None:
+                PCSCContext.instance.releaseContext()
+
+            PCSCContext.instance = PCSCContext.__PCSCContextSingleton()
+        finally:
+            PCSCContext.mutex.release()
+
+        return PCSCContext.instance.getContext()
+    renewContext = staticmethod(renewContext)
