@@ -2,7 +2,7 @@
 
 __author__ = "gemalto http://www.gemalto.com"
 
-Copyright 2001-2010 gemalto
+Copyright 2001-2012 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
 
 This file is part of pyscard.
@@ -23,13 +23,11 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 """
 
 
-class Reader:
+class Reader(object):
     """Reader abstract class.
 
     The reader class is responsible for creating connections
     with a card.
-
-    Known subclasses: PCSCReader
     """
 
     def __init__(self, readername):
@@ -49,11 +47,15 @@ class Reader:
         pass
 
     def __eq__(self, other):
-        """Returns 0 if self==other (same name)."""
+        """Returns True if self==other (same name)."""
         if type(other) == type(self):
             return self.name == other.name
         else:
-            return 1
+            return False
+
+    def __hash__(self):
+        """Returns a hash value for this object (self.name is unique)."""
+        return hash(self.name)
 
     def __repr__(self):
         """Returns card reader name string for `object` calls."""
