@@ -299,7 +299,7 @@ dump a byte list
 
 /**=======================================================================**/
 void SCardHelper_OutErrorStringAsPyObject(
-    ERRORSTRING* source, PyObject** ptarget )
+    ERRORSTRING source, PyObject** ptarget )
 /*===========================================================================
 Builds a Python string from an ERRORSTRING
 ===========================================================================*/
@@ -309,9 +309,9 @@ Builds a Python string from an ERRORSTRING
     if( NULL!=source )
     {
 #if (PY_MAJOR_VERSION >= 3) && defined(WIN32)
-        pystr = PyUnicode_Decode( (char*)source, strlen(source), "cp1250" , NULL);
+        pystr = PyUnicode_Decode( source, strlen(source), "cp1250" , NULL);
 #else
-        pystr = PyString_FromString( (char*)source );
+        pystr = PyString_FromString( source );
 #endif
         *ptarget = pystr;
     }
@@ -703,10 +703,13 @@ dump a reader state list
         }
         printf("\n");
 
+#ifdef WIN32
+		// SCARD_STATE_UNAWARE is 0 on Unix
         if(prl->ars[i].dwEventState & SCARD_STATE_UNAWARE)
         {
             printf("Card state unaware\n");
         }
+#endif
         if(prl->ars[i].dwEventState & SCARD_STATE_IGNORE)
         {
             printf("Card state ignore\n");
