@@ -109,7 +109,7 @@ class testcase_readers(unittest.TestCase):
 
 def suite():
     suite1 = unittest.makeSuite(testcase_readers)
-    return unittest.TestSuite((suite1))
+    return unittest.TestSuite(suite1)
 
 
 if __name__ == '__main__':
