@@ -181,7 +181,7 @@ class testcase_ulist(unittest.TestCase):
 
 def suite():
     suite1 = unittest.makeSuite(testcase_ulist)
-    return unittest.TestSuite((suite1))
+    return unittest.TestSuite(suite1)
 
 
 if __name__ == '__main__':
