@@ -107,7 +107,7 @@ class testcase_getAttrib(unittest.TestCase):
 
 def suite():
     suite1 = unittest.makeSuite(testcase_getAttrib)
-    return unittest.TestSuite((suite1))
+    return unittest.TestSuite(suite1)
 
 
 if __name__ == '__main__':
