@@ -124,7 +124,7 @@ class testcase_readergroups(unittest.TestCase):
 
 def suite():
     suite1 = unittest.makeSuite(testcase_readergroups)
-    return unittest.TestSuite((suite1))
+    return unittest.TestSuite(suite1)
 
 
 if __name__ == '__main__':
